url_from_abs_path

Function url_from_abs_path 

pub(crate) fn url_from_abs_path(path: &AbsPath) -> Url
Returns a Url object from a given path, will lowercase drive letters if present. This will only happen when processing windows paths.

When processing non-windows path, this is essentially the same as Url::from_file_path.